@@ -276,10 +276,18 @@ class Polygon2D(Base2DIn2D):
         start_i = outer_node.i
         vertices = [Point2D(outer_node.x, outer_node.y)]
         node = outer_node.next
+        node_counter, orig_start_i = 0, 0
         while node.i != start_i:
             vertices.append(Point2D(node.x, node.y))
+            node_counter += 1
+            if node.i == 0:
+                orig_start_i = node_counter
             node = node.next
 
+        # ensure that the starting vertex is the same as the input boundary
+        vertices = vertices[orig_start_i:] + vertices[:orig_start_i]
+        vertices[0] = boundary[0]  # this avoids issues of floating point tolerance
+
         # return the polygon with some properties set based on what we know
         _new_poly = cls(vertices)
         _new_poly._is_clockwise = bound_direction
@@ -585,7 +593,7 @@ class Polygon2D(Base2DIn2D):
 
         Args:
             distance: The distance inwards that the polygon will be offset.
-                Positive values will be offset inwards while negative ones
+                Positive values will always be offset inwards while negative ones
                 will be offset outwards.
             check_intersection: A boolean to note whether the resulting operation
                 should be checked for self intersection and, if so, None will be
@@ -596,30 +604,39 @@ class Polygon2D(Base2DIn2D):
             return self
 
         # loop through the vertices and get the new offset vectors
-        move_vecs, max_i = [], len(self._vertices) - 1
-        for i, pt in enumerate(self._vertices):
-            v1 = self._vertices[i - 1] - pt
+        init_verts = self._vertices if not self.is_clockwise \
+            else list(reversed(self._vertices))
+        init_verts = [pt for i, pt in enumerate(init_verts) if pt != init_verts[i - 1]]
+        move_vecs, max_i = [], len(init_verts) - 1
+        for i, pt in enumerate(init_verts):
+            v1 = init_verts[i - 1] - pt
             end_i = i + 1 if i != max_i else 0
-            v2 = self._vertices[end_i] - pt
+            v2 = init_verts[end_i] - pt
             if not self.is_clockwise:
                 ang = v1.angle_clockwise(v2) / 2
+                if ang == 0:
+                    ang = math.pi / 2
                 m_vec = v1.rotate(-ang).normalize()
                 m_dist = distance / math.sin(ang)
             else:
                 ang = v1.angle_counterclockwise(v2) / 2
+                if ang == 0:
+                    ang = math.pi / 2
                 m_vec = v1.rotate(ang).normalize()
                 m_dist = -distance / math.sin(ang)
             m_vec = m_vec * m_dist
             move_vecs.append(m_vec)
 
         # move the vertices by the offset to create the new Polygon2D
-        new_pts = tuple(pt.move(m_vec) for pt, m_vec in zip(self._vertices, move_vecs))
+        new_pts = tuple(pt.move(m_vec) for pt, m_vec in zip(init_verts, move_vecs))
+        if self.is_clockwise:
+            new_pts = tuple(reversed(new_pts))
         new_poly = Polygon2D(new_pts)
 
         # check for self intersection between the moving vectors if requested
         if check_intersection:
             poly_segs = new_poly.segments
-            _segs = [LineSegment2D(p, v) for p, v in zip(self._vertices, move_vecs)]
+            _segs = [LineSegment2D(p, v) for p, v in zip(init_verts, move_vecs)]
             _skip = (0, len(_segs) - 1)
             _other_segs = [x for j, x in enumerate(poly_segs) if j not in _skip]
             for _oth_s in _other_segs:
@@ -885,11 +902,11 @@ class Polygon2D(Base2DIn2D):
         return True
 
     def polygon_relationship(self, polygon, tolerance):
-        """Test whether another Polygon2D lies inside, outside or intersects this one.
+        """Test whether another Polygon2D lies inside, outside or overlaps this one.
 
         This method is not usually the fastest for understanding the relationship
         between polygons but it accurately accounts for tolerance such that the
-        case of the two polygons sharing an edge will not determine the outcome.
+        case of the two polygons sharing edges will not determine the outcome.
         Only when the polygon has vertices that are truly outside this polygon
         within the tolerance will the relationship become outside (or intersecting
         if one of the vertices is already inside within the tolerance).
@@ -908,16 +925,28 @@ class Polygon2D(Base2DIn2D):
 
             This will be one of the following:
 
-            * -1 = Outside polygon
-            *  0 = Intersects the polygon
-            * +1 = Inside polygon
+            * -1 = Outside this polygon
+            *  0 = Overlaps (intersects or contains) this polygon
+            * +1 = Inside this polygon
         """
-        pt_rels = [self.point_relationship(pt, tolerance) for pt in polygon]
-        if all(rel >= 0 for rel in pt_rels):
-            return 1
-        if all(rel <= 0 for rel in pt_rels):
-            return -1
-        return 0
+        # first evaluate the point relationships to rule out the inside case
+        pt_rels1 = [self.point_relationship(pt, tolerance) for pt in polygon]
+        pt_rels2 = [polygon.point_relationship(pt, tolerance) for pt in self]
+        if all(r1 >= 0 for r1 in pt_rels1) and all(r2 <= 0 for r2 in pt_rels2):
+            return 1  # definitely inside the polygon
+        if 1 in pt_rels1 or 1 in pt_rels2 or all(r2 == 0 for r2 in pt_rels2):
+            return 0  # definitely overlap in the polygons
+
+        # offset one of the polygons inward by the tolerance
+        off_poly = polygon.offset(tolerance)
+        # if any of the offset segments intersect the other polygon, there is overlap
+        for seg in self.segments:
+            for _s in off_poly.segments:
+                if does_intersection_exist_line2d(seg, _s):
+                    return 0
+
+        # we can reliably say that the polygons have nothing to do with one another
+        return -1
 
     def distance_to_point(self, point):
         """Get the minimum distance between this shape and the input point.
@@ -949,6 +978,37 @@ class Polygon2D(Base2DIn2D):
         """
         return min(seg.distance_to_point(point) for seg in self.segments)
 
+    def snap_to_polygon(self, polygon, tolerance):
+        """Snap another Polygon2D to this one for differences smaller than the tolerance.
+
+        This is useful to run before performing operations where small tolerance
+        differences are likely to cause issues, such as in boolean operations.
+
+        Args:
+            polygon: A Polygon2D which will be snapped to the current polygon.
+            tolerance: The minimum distance at which points will be snapped.
+
+        Returns:
+            A version of the polygon that is snapped to this Polygon2D.
+        """
+        new_verts = []
+        for pt in polygon.vertices:
+            # first check if the point can be snapped to a vertex
+            for s_pt in self.vertices:
+                if pt.is_equivalent(s_pt, tolerance):
+                    new_verts.append(s_pt)
+                    break
+            else:
+                # check if the point can be snapped to a segment
+                for seg in self.segments:
+                    s_pt = seg.closest_point(pt)
+                    if s_pt.distance_to_point(pt) <= tolerance:
+                        new_verts.append(s_pt)
+                        break
+                else:  # point could not be snapped
+                    new_verts.append(pt)
+        return Polygon2D(new_verts)
+
     def to_dict(self):
         """Get Polygon2D as a dictionary."""
         return {'type': 'Polygon2D',
@@ -971,7 +1031,7 @@ class Polygon2D(Base2DIn2D):
     def _from_bool_poly(bool_polygon):
         """Get a list of Polygon2D from a BooleanPolygon object."""
         return [Polygon2D(tuple(Point2D(pt.x, pt.y) for pt in new_poly))
-                for new_poly in bool_polygon.regions]
+                for new_poly in bool_polygon.regions if len(new_poly) > 2]
 
     def boolean_union(self, polygon, tolerance):
         """Get a list of Polygon2D for the union of this Polygon and another.
